@@ -15,28 +15,32 @@
 
 
 #include "components/audio/effect.h"
+#include "components/audio/effect_parameter_chain.h"
 #include <vector>
 	using std::vector;
 /**
 @author Juan Linietsky
 */
-class Effect_Chain {
+class Effect_Chain : public SigC::Object {
 
 	vector<Effect*> chain;
+	Effect_Parameter_Chain *chain_params;
+	
+	SigC::Connection chain_connection_change;
+	SigC::Connection chain_connection_delete;
 
-
+	void erase_chain();
+	void update_chain();	
 public:
 
-	void add_effect(Effect *p_effect);
 	int get_effect_count();
 	Effect* get_effect(int p_which);
-	bool remove_effect(int p_which);
-
-	bool move_effect_up(int p_which);
-	bool move_effect_down(int p_which);
-
-	void process_buffer(sample_t *p_buffer,int p_length,bool p_stereo,int p_mix_freq);
 
+	void process_buffer(sample_t *p_buffer,int p_length);
+	
+	void set_chain_params(Effect_Parameter_Chain *chain_params);
+	
+	
 
 	Effect_Chain();
 	~Effect_Chain();
