@@ -20,11 +20,16 @@ void Voice::clear_status() {
 	removed=false;
 }
 
+void Voice::removed_from_mixer_override() {
+
+
+}
 
 void Voice::remove_from_mixer() {
 
 	removed=true;
 	on_removal.emit();
+	removed_from_mixer_override();
 }
 bool Voice::was_removed_from_mixer() {
 
