@@ -38,7 +38,7 @@ public slots:
 
 public:
 
-	Effect * get_selected_effect();
+	Effect::Parameters *get_selected_effect_params();
 
 	Effect_Select_Popup();
 	~Effect_Select_Popup();
