@@ -29,7 +29,7 @@ class Effect_Distort : public Effect{
 public:
 
 	void reset();
-        void process_buffer(sample_32s_t* p_buffer,int p_length,bool p_stereo_samples,int p_buffer_freq);
+        void process_buffer(sample_t* p_buffer,int p_length,bool p_stereo_samples,int p_buffer_freq);
 	string get_name();
 	string get_display_name();
 	list<Property_Bridge*> get_properties();
